@@ -39,19 +39,19 @@ class UserController(blnt.Controller):
     @get('/me',
          access=types.web.AccessToken.Fresh,
          returns=('user', 'private'))
-    async def me(self, current_user, **_):
+    async def me(self, current_user):
         return response.ok('OK', current_user)
 
     @get('/info',
          access=types.web.AccessToken.Required,
          returns=('user', 'private'))
-    async def info(self, current_user, **_):
+    async def info(self, current_user):
         return response.ok('OK', current_user)
 
     @post('/login',
           returns=('user', 'private'),
           expects=('user', 'login'))
-    async def login(self, payload, **_):
+    async def login(self, payload):
         username = payload['username']
         password = payload['password']
         try:
@@ -66,7 +66,7 @@ class UserController(blnt.Controller):
         return response.unauthorized('user.login.wrong_credentials')
 
     @post('/logout')
-    async def logout(self, **_):
+    async def logout(self):
         resp = response.ok('user.logout.success')
         resp.cookies.append(Cookie('access_token', None, delete=True, path='/'))
         resp.cookies.append(Cookie('refresh_token', None, delete=True, path='/api/user/refresh'))
@@ -74,7 +74,7 @@ class UserController(blnt.Controller):
 
     @post('/token/refresh',
           access=types.web.AccessToken.Refresh)
-    async def refresh(self, current_user, **_):
+    async def refresh(self, current_user):
         resp = response.ok('user.token.refreshed')
         self._create_tokens(resp, current_user, set_access=True, set_refresh=False, fresh=False)
         return resp
@@ -82,7 +82,7 @@ class UserController(blnt.Controller):
     @post('/register',
           returns=('user', 'private'),
           expects=('user', 'register'))
-    async def register(self, payload, **_):
+    async def register(self, payload):
         if env.init.get('ADMIN_REGISTER_ONLY', True):
             raise BadRequestError('global.register.admin_only')
         user = await self.user_service.create(payload)
@@ -94,7 +94,7 @@ class UserController(blnt.Controller):
           roles=['admin'],
           returns=('user', 'private'),
           expects=('user', 'admin_register'))
-    async def admin_register(self, payload, **_):
+    async def admin_register(self, payload):
         # send_mail = payload.pop('send_mail')
         payload['password'] = ''.join(random.choices(string.ascii_lowercase, k=32))
         user = await self.user_service.create(payload)
@@ -106,7 +106,7 @@ class UserController(blnt.Controller):
            access=types.web.AccessToken.Fresh,
            returns=('user', 'private'),
            expects=('user', 'register', 'patch'))
-    async def update_user(self, payload, current_user, **_):
+    async def update_user(self, payload, current_user):
         user = await self.user_service.patch(current_user, payload)
         resp = response.ok('user.updated', user)
         self._create_tokens(resp, user, set_access=True, set_refresh=True, fresh=True)
@@ -117,7 +117,7 @@ class UserController(blnt.Controller):
           roles=['admin'],
           expects='role',
           returns=('user', 'private'))
-    async def add_user_role(self, match, payload, **_):
+    async def add_user_role(self, match, payload):
         user = await self.user_service.get_by_username(match['username'])
         role = await self.role_service.get_by_name(payload['name'])
         await self.user_service.add_role(user, role)
@@ -127,7 +127,7 @@ class UserController(blnt.Controller):
             access=types.web.AccessToken.Required,
             roles=['admin'],
             returns=('user', 'private'))
-    async def delete_user_role(self, match, current_user, **_):
+    async def delete_user_role(self, match, current_user):
         user = await self.user_service.get_by_username(match['username'])
         role = await self.role_service.get_by_name(match['role'])
         await self.user_service.remove_role(current_user, user, role)
@@ -136,7 +136,7 @@ class UserController(blnt.Controller):
     @post('/picture',
           access=types.web.AccessToken.Required,
           returns=('user', 'private'))
-    async def upload_profile_picture(self, current_user, payload, **_):
+    async def upload_profile_picture(self, current_user, payload):
         picture = payload['file']
         user = await self.user_service.save_profile_picture(current_user, picture)
         return response.ok(f'user.picture.uploaded', user)
