@@ -1,9 +1,9 @@
-from bolinette import types, data
+from bolinette import types, blnt
 from bolinette.decorators import model
 
 
 @model('file')
-class File(data.Model):
+class File(blnt.Model):
     id = types.defs.Column(types.db.Integer, primary_key=True)
     key = types.defs.Column(types.db.String, nullable=False)
     name = types.defs.Column(types.db.String, nullable=False)
