@@ -1,9 +1,10 @@
 import random
 import string
 
+from bolinette_common import paths
+
 from bolinette import blnt, env
 from bolinette.decorators import service
-from bolinette.utils import fs
 
 
 @service('file')
@@ -16,15 +17,15 @@ class FileService(blnt.Service):
 
     async def write_file(self, content, key):
         path = env.instance_path('uploads')
-        if not fs.exists(path):
-            fs.mkdir(path)
-        with open(fs.join(path, key), 'wb') as f:
+        if not paths.exists(path):
+            paths.mkdir(path)
+        with open(paths.join(path, key), 'wb') as f:
             f.write(content)
 
     async def delete_file(self, key):
-        fs.delete(env.instance_path('uploads', key))
+        paths.delete(env.instance_path('uploads', key))
 
-    async def delete(self, entity, **_):
+    async def delete(self, entity):
         ent = await super().delete(entity)
         await self.delete_file(entity.key)
         return ent
