@@ -1,11 +1,11 @@
 import pytz
 
-from bolinette import data
+from bolinette import blnt
 from bolinette.decorators import service
 
 
 @service('tz')
-class TimezoneService(data.SimpleService):
+class TimezoneService(blnt.SimpleService):
     async def get_all(self):
         return [tz for tz in pytz.all_timezones]
 
