@@ -1,8 +1,7 @@
 import requests
-
+from bolinette_common import logger
 
 from bolinette import env
-from bolinette.utils import logger
 
 
 class Mailgun:
